@@ -1,7 +1,9 @@
+#' @method predict multnet
+#' @export
 predict.multnet <-
-  function (object, newx, s = NULL, type = c("link", "response", 
-                                      "coefficients", "class", "nonzero"), exact = FALSE, offset, 
-            ...) 
+  function (object, newx, s = NULL, type = c("link", "response",
+                                      "coefficients", "class", "nonzero"), exact = FALSE, newoffset,
+            ...)
 {
   type = match.arg(type)
     ###multnet  is very different, so we treat it separately
@@ -13,8 +15,8 @@ predict.multnet <-
     which=match(s,lambda,FALSE)
     if(!all(which>0)){
       lambda=unique(rev(sort(c(s,lambda))))
-      ### Now we check if x and y were supplied; if not, we try
-      object=tryCatch(update(object,lambda=lambda,...),error=function(e)stop("problem with predict.glmnet() or coef.glmnet(): unable to refit the glmnet object to compute exact coefficients; please supply original data by name, such as x and y, plus any weights, offsets etc.",call.=FALSE))
+      check_dots(object,...)# This fails if you don't supply the crucial arguments
+      object=update(object,lambda=lambda,...)
     }
   }
 
@@ -31,7 +33,7 @@ predict.multnet <-
       kbeta = methods::rbind2(a0[i, , drop = FALSE], nbeta[[i]])#was rbind2
       vnames = dimnames(kbeta)[[1]]
       dimnames(kbeta) = list(NULL, NULL)
-      kbeta = kbeta[, lamlist$left, drop = FALSE] %*% Diagonal(x=lamlist$frac) + 
+      kbeta = kbeta[, lamlist$left, drop = FALSE] %*% Diagonal(x=lamlist$frac) +
         kbeta[, lamlist$right, drop = FALSE] %*% Diagonal(x=1 - lamlist$frac)
       dimnames(kbeta) = list(vnames, paste(seq(along = s)))
       nbeta[[i]] = kbeta
@@ -41,15 +43,15 @@ predict.multnet <-
     for (i in seq(nclass)) nbeta[[i]] = methods::rbind2(a0[i, ], nbeta[[i]])#was rbind2
     nlambda=length(object$lambda)
   }
-  if (type == "coefficients") 
+  if (type == "coefficients")
     return(nbeta)
   if (type == "nonzero")
     if(object$grouped)return(nonzeroCoef(object$beta[[1]],bystep=TRUE))
     else
-      return(lapply(nbeta, function(x) nonzeroCoef(x[-1, , 
+      return(lapply(nbeta, function(x) nonzeroCoef(x[-1, ,
                                                    drop = FALSE], bystep = TRUE)))
   dd = dim(newx)
-   if (inherits(newx, "sparseMatrix")) 
+   if (inherits(newx, "sparseMatrix"))
     newx = as(newx, "dgCMatrix")
   npred = dd[[1]]
   dn = list(names(nbeta), dimnames(nbeta[[1]])[[2]], dimnames(newx)[[1]])
@@ -59,13 +61,13 @@ predict.multnet <-
     dp[i, , ] = dp[i, , ] + t(as.matrix(fitk))
   }
   if (object$offset) {
-    if (missing(offset)) 
-      stop("No offset provided for prediction, yet used in fit of glmnet", 
+    if (missing(newoffset))
+      stop("No newoffset provided for prediction, yet offset used in fit of glmnet",
            call. = FALSE)
-    if (!is.matrix(offset) || dim(offset)[[2]] != nclass) 
-      stop(paste("Offset should be dimension", npred, "x", 
+    if (!is.matrix(newoffset) || dim(newoffset)[[2]] != nclass)
+      stop(paste("Dimension of newoffset should be", npred, "x",
                  nclass), call. = FALSE)
-    toff = t(offset)
+    toff = t(newoffset)
     for (i in seq(nlambda)) {
       dp[, i, ] = dp[, i, ] + toff
     }
@@ -73,7 +75,7 @@ predict.multnet <-
   switch(type, response = {
     pp = exp(dp)
     psum = apply(pp, c(2, 3), sum)
-    aperm(pp/rep(psum, rep(nclass, nlambda * npred)), c(3, 
+    aperm(pp/rep(psum, rep(nclass, nlambda * npred)), c(3,
                                                         1, 2))
   }, link = aperm(dp, c(3, 1, 2)), class = {
     dp = aperm(dp, c(3, 1, 2))
